.. Tihi documentation master file, created by
   sphinx-quickstart on Thu Jun 27 08:39:33 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Tihi's documentation!
================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   tihi/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
